"""
Utility class used to export data from Tensorflow summaries
"""

import os

import numpy as np
import scipy.misc
import tensorflow as tf


def save_images_from_event(sess, fn, tag, output_name, output_dir='./'):
    assert (os.path.isdir(output_dir))

    image_str = tf.placeholder(tf.string)
    im_tf = tf.image.decode_image(image_str)

    with sess.as_default():
        count = 0
        for e in tf.train.summary_iterator(fn):
            for v in e.summary.value:
                if v.tag == tag:
                    im = im_tf.eval({image_str: v.image.encoded_image_string})
                    output_fn = os.path.realpath('{}/{}_{}.png'.format(output_dir, count, output_name))
                    print("Saving '{}'".format(output_fn))
                    if im.shape[2] == 1:
                        im = np.squeeze(im, axis=2)
                    scipy.misc.imsave(output_fn, im)
                    count += 1


def main(unused_argv):
    sess = tf.InteractiveSession()
    try:
        os.makedirs('../output_images')
    except os.error:
        pass
    checkpoint_folder = '20181221-1907/events.out.tfevents.1545415653.DESKTOP-UJPQSV4'
    save_images_from_event(sess=sess, fn='../checkpoints/' + checkpoint_folder,
                           tag='unsup/input/image/0',
                           output_name='G_input', output_dir='../output_images')
    save_images_from_event(sess=sess, fn='../checkpoints/' + checkpoint_folder,
                           tag='unsup/G_output/image/0',
                           output_name='G_outptut', output_dir='../output_images')
    save_images_from_event(sess=sess, fn='../checkpoints/' + checkpoint_folder,
                           tag='unsup/D_output/image/0',
                           output_name='D_outptut', output_dir='../output_images')
    save_images_from_event(sess=sess, fn='../checkpoints/' + checkpoint_folder,
                           tag='unsup/mask/image/0',
                           output_name='mask', output_dir='../output_images')


if __name__ == '__main__':
    tf.app.run()
